/// <reference types="highlight.js" />

import type { BytemdPlugin } from 'bytemd';
import { LanguageFn } from 'highlight.js';

declare function highlightSsr({ subset, ignoreMissing, ...rest }: Options): BytemdPlugin;
export default highlightSsr;

declare type Options = Options_2

/**
 * Configuration (optional).
 */
declare type Options_2 = {
    /**
     * Prefix to use before classes.
     */
    prefix?: string | undefined
    /**
     * Scope of languages to check when auto-detecting (default: all languages).
     * Pass `false` to not highlight code without language classes.
     */
    subset?: boolean | string[] | undefined
    /**
     * Swallow errors for missing languages.
     * By default, unregistered syntaxes throw an error when they are used.
     * Pass `true` to swallow those errors and thus ignore code with unknown code
     * languages.
     */
    ignoreMissing?: boolean | undefined
    /**
     * List of plain-text languages.
     * Pass any languages you would like to be kept as plain-text instead of
     * getting highlighted.
     */
    plainText?: string[] | undefined
    /**
     * Register more aliases.
     * Passed to `lowlight.registerAlias`.
     */
    aliases?: Record<string, string | string[]> | undefined
    /**
     * Register more languages.
     * Each key/value pair passed as arguments to `lowlight.registerLanguage`.
     */
    languages?: Record<string, LanguageFn> | undefined
}

export { }
